﻿/*
Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.editorConfig = function( config )
{
    config.uiColor = '#D4D0C8';
    config.skin = 'kama';
    config.removePlugins = "elementspath,maximize,resize";
    config.scayt_autoStartup = false;
    config.enterMode = CKEDITOR.ENTER_BR;
};
